## Product details

Introductions:

Are you looking for a comfortable sofa for your family?  If so, this Oak Armrest Oak Upholstered Single Lounge Chair Indoor Lounge Chair is highly recommended to you. This modern sofa can provide ample seating when guests are over, perfect for a small space and easy to lay down on for a nap. The cushions you sit on are nice and firm.  Don't worry about sinking in. So what are you waiting for? Don't hesitate, it's worth buying!



Specifications:
1. Material: Solid Wood,Corduroy
2. Color: Off White/Beige/Khaki/Light Gray/Olive Green/Brown/Dark Gray/Orange/White/Light Blue
3. Dimensions: (25.59 x 29.53 x 31.89)"(L x W x H)
4. Weight Capacity:330 lbs



Package Includes:
1 x Accent Chair

The fabric material is corduroy,the advantages of Corduroy is Comfort,Style, Easy to care for,Versatility and Durability.

This mid-century accent chair with back and seat cushion can provides ample seating when sit in.  And a lumbar pillow will come with the item.

The design of the chair is ergonomic compliance, the back leans a little back to help you lean back in your chair.

The solid wood frame are strong and durable, weight Capacity is up to 330 lbs.

Suitable for your living room, study, bedroom and other leisure areas.

Comfortable Cushioning: Luxuriously soft and warm cushions for both the seat and backrest, ensuring optimal relaxation.

Easy to install

info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Fabric content
Corduroy
Frame material
Solid Wood
Home decor style
Mid-Century
Max load
330 lb
More details
## Warranty

Warranty information
Please be aware that the warranty terms on items offered for sale by third party Marketplace sellers may differ from those displayed in this section (if any). To confirm warranty terms on an item offered for sale by a third party Marketplace seller, please use the 'Contact seller' feature on the third party Marketplace seller's information page and request the item's warranty terms prior to purchase.
